@@ -19,7 +19,7 @@
 # Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 # Some ideas taken from KeyLauch (thanks to Ken Lynch and Stefan Pfetzing)
-# Feel free to contact me at <arnau@ehas.org>
+# Feel free to contact me at <arnau@ehas.org>s
 
 # Python modules
 import os, sys, time, signal
@@ -988,8 +988,9 @@ class Xhotkeys:
 		self.fill_table()
 		if self.check_active(): self.widgets["status"].push(0, " Xhotkeys daemon is running (pid %d)" %self.daemon_pid)
 		else: self.widgets["status"].push(0, " Xhotkeys daemon is not running")
-		
 		self.configure_signals([signal.SIGTERM, signal.SIGINT])
+		iconfile = "/usr/share/%s/%s.png"%(NAME, NAME)
+		gtk.window_set_default_icon_from_file(iconfile)
 		self.widgets["mainwindow"].show()
 		gtk.main()
 
